@@ -1,5 +1,4 @@
-from __future__ import absolute_import
-from __future__ import with_statement
+from __future__ import absolute_import, unicode_literals
 
 from anyjson import loads
 
@@ -19,14 +18,17 @@ from celery.task.control import broadcast, revoke, rate_limit
 from celery.utils.text import abbrtask
 
 from .admin_utils import action, display_field, fixedwidth
-from .models import (TaskState, WorkerState,
-                     PeriodicTask, IntervalSchedule, CrontabSchedule)
+from .models import (
+    TaskState, WorkerState,
+    PeriodicTask, IntervalSchedule, CrontabSchedule,
+)
 from .humanize import naturaldate
+from .utils import is_database_scheduler
 
 try:
     from django.utils.encoding import force_text
 except ImportError:
-    from django.utils.encoding import force_unicode as force_text
+    from django.utils.encoding import force_unicode as force_text  # noqa
 
 
 TASK_STATE_COLORS = {states.SUCCESS: 'green',
@@ -50,14 +52,14 @@ class MonitorList(main_views.ChangeList):
 def colored_state(task):
     state = escape(task.state)
     color = TASK_STATE_COLORS.get(task.state, 'black')
-    return '<b><span style="color: %s;">%s</span></b>' % (color, state)
+    return '<b><span style="color: {0};">{1}</span></b>'.format(color, state)
 
 
 @display_field(_('state'), 'last_heartbeat')
 def node_state(node):
     state = node.is_alive() and 'ONLINE' or 'OFFLINE'
     color = NODE_STATE_COLORS[state]
-    return '<b><span style="color: %s;">%s</span></b>' % (color, state)
+    return '<b><span style="color: {0};">{1}</span></b>'.format(color, state)
 
 
 @display_field(_('ETA'), 'eta')
@@ -69,15 +71,17 @@ def eta(task):
 
 @display_field(_('when'), 'tstamp')
 def tstamp(task):
-    return '<div title="%s">%s</div>' % (escape(str(task.tstamp)),
-                                         escape(naturaldate(task.tstamp)))
+    return '<div title="{0}">{1}</div>'.format(
+        escape(str(task.tstamp)), escape(naturaldate(task.tstamp)),
+    )
 
 
 @display_field(_('name'), 'name')
 def name(task):
     short_name = abbrtask(task.name, 16)
-    return '<div title="%s"><b>%s</b></div>' % (escape(task.name),
-                                                escape(short_name))
+    return '<div title="{0}"><b>{1}</b></div>'.format(
+        escape(task.name), escape(short_name),
+    )
 
 
 class ModelMonitor(admin.ModelAdmin):
@@ -138,12 +142,10 @@ class TaskMonitor(ModelMonitor):
     )
     list_filter = ('state', 'name', 'tstamp', 'eta', 'worker')
     search_fields = ('name', 'task_id', 'args', 'kwargs', 'worker__hostname')
-    actions = [
-        'revoke_tasks',
-        'terminate_tasks',
-        'kill_tasks',
-        'rate_limit_tasks',
-    ]
+    actions = ['revoke_tasks',
+               'terminate_tasks',
+               'kill_tasks',
+               'rate_limit_tasks']
 
     class Media:
         css = {'all': ('djcelery/style.css', )}
@@ -252,7 +254,7 @@ def periodic_task_form():
     choices = (('', ''), ) + tuple(zip(tasks, tasks))
 
     class PeriodicTaskForm(forms.ModelForm):
-        regtask = LaxChoiceField(label=_(u'Task (registered)'),
+        regtask = LaxChoiceField(label=_('Task (registered)'),
                                  choices=choices, required=False)
         task = forms.CharField(label=_('Task (custom)'), required=False,
                                max_length=200)
@@ -266,7 +268,7 @@ def periodic_task_form():
             if regtask:
                 data['task'] = regtask
             if not data['task']:
-                exc = forms.ValidationError(_(u'Need name of task'))
+                exc = forms.ValidationError(_('Need name of task'))
                 self._errors['task'] = self.error_class(exc.messages)
                 raise exc
             return data
@@ -320,8 +322,7 @@ class PeriodicTaskAdmin(admin.ModelAdmin):
     def changelist_view(self, request, extra_context=None):
         extra_context = extra_context or {}
         scheduler = getattr(settings, 'CELERYBEAT_SCHEDULER', None)
-        if scheduler != 'djcelery.schedulers.DatabaseScheduler':
-            extra_context['wrong_scheduler'] = True
+        extra_context['wrong_scheduler'] = not is_database_scheduler(scheduler)
         return super(PeriodicTaskAdmin, self).changelist_view(request,
                                                               extra_context)
 
