@@ -8,8 +8,8 @@ import warnings
 from datetime import datetime
 
 from celery import signals
-from celery.loaders.base import BaseLoader
 from celery.datastructures import DictAttribute
+from celery.loaders.base import BaseLoader
 
 import django
 from django import db
@@ -77,7 +77,7 @@ class DjangoLoader(BaseLoader):
         for close in funs:
             try:
                 close()
-            except DATABASE_ERRORS, exc:
+            except DATABASE_ERRORS as exc:
                 str_exc = str(exc)
                 if 'closed' not in str_exc and 'not connected' not in str_exc:
                     raise
@@ -192,4 +192,4 @@ def find_related_module(app, related_name):
     except ImportError:
         return
 
-    return importlib.import_module('%s.%s' % (app, related_name))
+    return importlib.import_module('{0}.{1}'.format(app, related_name))
