@@ -3,7 +3,7 @@
 Start detached worker node from the Django management utility.
 
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 import os
 import sys
