@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 from datetime import timedelta
 from time import time, mktime
@@ -22,24 +22,24 @@ TASK_STATE_CHOICES = zip(states.ALL_STATES, states.ALL_STATES)
 
 class TaskMeta(models.Model):
     """Task result/status."""
-    task_id = models.CharField(_(u'task id'), max_length=255, unique=True)
+    task_id = models.CharField(_('task id'), max_length=255, unique=True)
     status = models.CharField(
-        _(u'state'),
+        _('state'),
         max_length=50, default=states.PENDING, choices=TASK_STATE_CHOICES,
     )
     result = PickledObjectField(null=True, default=None, editable=False)
-    date_done = models.DateTimeField(_(u'done at'), auto_now=True)
-    traceback = models.TextField(_(u'traceback'), blank=True, null=True)
+    date_done = models.DateTimeField(_('done at'), auto_now=True)
+    traceback = models.TextField(_('traceback'), blank=True, null=True)
     hidden = models.BooleanField(editable=False, default=False, db_index=True)
     meta = PickledObjectField(
-        _(u'meta'), null=True, default=None, editable=False,
+        _('meta'), null=True, default=None, editable=False,
     )
 
     objects = managers.TaskManager()
 
     class Meta:
-        verbose_name = _(u'task state')
-        verbose_name_plural = _(u'task states')
+        verbose_name = _('task state')
+        verbose_name_plural = _('task states')
         db_table = 'celery_taskmeta'
 
     def to_dict(self):
@@ -51,22 +51,22 @@ class TaskMeta(models.Model):
                 'children': (self.meta or {}).get('children')}
 
     def __unicode__(self):
-        return u'<Task: %s state=%s>' % (self.task_id, self.status)
+        return '<Task: {0.task_id} state={0.status}>'.format(self)
 
 
 class TaskSetMeta(models.Model):
     """TaskSet result"""
-    taskset_id = models.CharField(_(u'group id'), max_length=255, unique=True)
+    taskset_id = models.CharField(_('group id'), max_length=255, unique=True)
     result = PickledObjectField()
-    date_done = models.DateTimeField(_(u'created at'), auto_now=True)
+    date_done = models.DateTimeField(_('created at'), auto_now=True)
     hidden = models.BooleanField(editable=False, default=False, db_index=True)
 
     objects = managers.TaskSetManager()
 
     class Meta:
         """Model meta-data."""
-        verbose_name = _(u'saved group result')
-        verbose_name_plural = _(u'saved group results')
+        verbose_name = _('saved group result')
+        verbose_name_plural = _('saved group results')
         db_table = 'celery_tasksetmeta'
 
     def to_dict(self):
@@ -75,25 +75,25 @@ class TaskSetMeta(models.Model):
                 'date_done': self.date_done}
 
     def __unicode__(self):
-        return u'<TaskSet: %s>' % (self.taskset_id)
+        return '<TaskSet: {0.taskset_id}>'.format(self)
 
 
-PERIOD_CHOICES = (('days', _(u'Days')),
-                  ('hours', _(u'Hours')),
-                  ('minutes', _(u'Minutes')),
-                  ('seconds', _(u'Seconds')),
-                  ('microseconds', _(u'Microseconds')))
+PERIOD_CHOICES = (('days', _('Days')),
+                  ('hours', _('Hours')),
+                  ('minutes', _('Minutes')),
+                  ('seconds', _('Seconds')),
+                  ('microseconds', _('Microseconds')))
 
 
 class IntervalSchedule(models.Model):
-    every = models.IntegerField(_(u'every'), null=False)
+    every = models.IntegerField(_('every'), null=False)
     period = models.CharField(
-        _(u'period'), max_length=24, choices=PERIOD_CHOICES,
+        _('period'), max_length=24, choices=PERIOD_CHOICES,
     )
 
     class Meta:
-        verbose_name = _(u'interval')
-        verbose_name_plural = _(u'intervals')
+        verbose_name = _('interval')
+        verbose_name_plural = _('intervals')
         ordering = ['period', 'every']
 
     @property
@@ -113,41 +113,39 @@ class IntervalSchedule(models.Model):
 
     def __unicode__(self):
         if self.every == 1:
-            return _(u'every %(period)s') % {'period': self.period[:-1]}
-        return _(u'every %(every)s %(period)s') % {'every': self.every,
-                                                   'period': self.period}
+            return _('every {0.period_singular}').format(self)
+        return _('every {0.every} {0.period}').format(self)
+
+    @property
+    def period_singular(self):
+        return self.period[:-1]
 
 
 class CrontabSchedule(models.Model):
-    minute = models.CharField(
-        _(u'minute'), max_length=64, default='*',
-    )
-    hour = models.CharField(
-        _(u'hour'), max_length=64, default='*',
-    )
+    minute = models.CharField(_('minute'), max_length=64, default='*')
+    hour = models.CharField(_('hour'), max_length=64, default='*')
     day_of_week = models.CharField(
-        _(u'day of week'), max_length=64, default='*',
+        _('day of week'), max_length=64, default='*',
     )
     day_of_month = models.CharField(
-        _(u'day of month'), max_length=64, default='*',
+        _('day of month'), max_length=64, default='*',
     )
     month_of_year = models.CharField(
-        _(u'month of year'), max_length=64, default='*',
+        _('month of year'), max_length=64, default='*',
     )
 
     class Meta:
-        verbose_name = _(u'crontab')
-        verbose_name_plural = _(u'crontabs')
+        verbose_name = _('crontab')
+        verbose_name_plural = _('crontabs')
         ordering = ['month_of_year', 'day_of_month',
                     'day_of_week', 'hour', 'minute']
 
     def __unicode__(self):
         rfield = lambda f: f and str(f).replace(' ', '') or '*'
-        return u'%s %s %s %s %s (m/h/d/dM/MY)' % (rfield(self.minute),
-                                                  rfield(self.hour),
-                                                  rfield(self.day_of_week),
-                                                  rfield(self.day_of_month),
-                                                  rfield(self.month_of_year))
+        return '{0} {1} {2} {3} {4} (m/h/d/dM/MY)'.format(
+            rfield(self.minute), rfield(self.hour), rfield(self.day_of_week),
+            rfield(self.day_of_month), rfield(self.month_of_year),
+        )
 
     @property
     def schedule(self):
@@ -194,41 +192,42 @@ class PeriodicTasks(models.Model):
 
 
 class PeriodicTask(models.Model):
-    name = models.CharField(_(u'name'), max_length=200, unique=True,
-                            help_text=_(u'Useful description'))
-    task = models.CharField(_(u'task name'), max_length=200)
+    name = models.CharField(
+        _('name'), max_length=200, unique=True,
+        help_text=_('Useful description'),
+    )
+    task = models.CharField(_('task name'), max_length=200)
     interval = models.ForeignKey(
         IntervalSchedule,
-        null=True, blank=True, verbose_name=_(u'interval'),
+        null=True, blank=True, verbose_name=_('interval'),
     )
     crontab = models.ForeignKey(
-        CrontabSchedule,
-        null=True, blank=True, verbose_name=_(u'crontab'),
-        help_text=_(u'Use one of interval/crontab'),
+        CrontabSchedule, null=True, blank=True, verbose_name=_('crontab'),
+        help_text=_('Use one of interval/crontab'),
     )
     args = models.TextField(
-        _(u'Arguments'), blank=True, default='[]',
-        help_text=_(u'JSON encoded positional arguments'),
+        _('Arguments'), blank=True, default='[]',
+        help_text=_('JSON encoded positional arguments'),
     )
     kwargs = models.TextField(
-        _(u'Keyword arguments'), blank=True, default='{}',
+        _('Keyword arguments'), blank=True, default='{}',
         help_text=_('JSON encoded keyword arguments'),
     )
     queue = models.CharField(
         _('queue'), max_length=200, blank=True, null=True, default=None,
-        help_text=_(u'Queue defined in CELERY_QUEUES'),
+        help_text=_('Queue defined in CELERY_QUEUES'),
     )
     exchange = models.CharField(
-        _(u'exchange'), max_length=200, blank=True, null=True, default=None,
+        _('exchange'), max_length=200, blank=True, null=True, default=None,
     )
     routing_key = models.CharField(
-        _(u'routing key'), max_length=200, blank=True, null=True, default=None,
+        _('routing key'), max_length=200, blank=True, null=True, default=None,
     )
     expires = models.DateTimeField(
-        _(u'expires'), blank=True, null=True,
+        _('expires'), blank=True, null=True,
     )
     enabled = models.BooleanField(
-        _(u'enabled'), default=True,
+        _('enabled'), default=True,
     )
     last_run_at = models.DateTimeField(
         auto_now=False, auto_now_add=False,
@@ -244,8 +243,8 @@ class PeriodicTask(models.Model):
     no_changes = False
 
     class Meta:
-        verbose_name = _(u'periodic task')
-        verbose_name_plural = _(u'periodic tasks')
+        verbose_name = _('periodic task')
+        verbose_name_plural = _('periodic tasks')
 
     def validate_unique(self, *args, **kwargs):
         super(PeriodicTask, self).validate_unique(*args, **kwargs)
@@ -265,11 +264,12 @@ class PeriodicTask(models.Model):
         super(PeriodicTask, self).save(*args, **kwargs)
 
     def __unicode__(self):
+        fmt = '{0.name}: {{no schedule}}'
         if self.interval:
-            return u'%s: %s' % (self.name, unicode(self.interval))
+            fmt = '{0.name}: {0.interval}'
         if self.crontab:
-            return u'%s: %s' % (self.name, unicode(self.crontab))
-        return u'%s: {no schedule}' % (self.name, )
+            fmt = '{0.name}: {0.crontab}'
+        return fmt.format(self)
 
     @property
     def schedule(self):
@@ -283,16 +283,16 @@ signals.pre_save.connect(PeriodicTasks.changed, sender=PeriodicTask)
 
 
 class WorkerState(models.Model):
-    hostname = models.CharField(_(u'hostname'), max_length=255, unique=True)
-    last_heartbeat = models.DateTimeField(_(u'last heartbeat'), null=True,
+    hostname = models.CharField(_('hostname'), max_length=255, unique=True)
+    last_heartbeat = models.DateTimeField(_('last heartbeat'), null=True,
                                           db_index=True)
 
     objects = managers.ExtendedManager()
 
     class Meta:
         """Model meta-data."""
-        verbose_name = _(u'worker')
-        verbose_name_plural = _(u'workers')
+        verbose_name = _('worker')
+        verbose_name_plural = _('workers')
         get_latest_by = 'last_heartbeat'
         ordering = ['-last_heartbeat']
 
@@ -300,7 +300,7 @@ class WorkerState(models.Model):
         return self.hostname
 
     def __repr__(self):
-        return '<WorkerState: %s>' % (self.hostname, )
+        return '<WorkerState: {0.hostname}>'.format(self)
 
     def is_alive(self):
         if self.last_heartbeat:
@@ -314,31 +314,24 @@ class WorkerState(models.Model):
 
 class TaskState(models.Model):
     state = models.CharField(
-        _(u'state'), max_length=64, choices=TASK_STATE_CHOICES, db_index=True,
-    )
-    task_id = models.CharField(
-        _(u'UUID'), max_length=36, unique=True,
+        _('state'), max_length=64, choices=TASK_STATE_CHOICES, db_index=True,
     )
+    task_id = models.CharField(_('UUID'), max_length=36, unique=True)
     name = models.CharField(
-        _(u'name'), max_length=200, null=True, db_index=True,
+        _('name'), max_length=200, null=True, db_index=True,
     )
-    tstamp = models.DateTimeField(
-        _(u'event received at'), db_index=True,
-    )
-    args = models.TextField(_(u'Arguments'), null=True)
-    kwargs = models.TextField(_(u'Keyword arguments'), null=True)
-    eta = models.DateTimeField(
-        _(u'ETA'), null=True,
-        help_text=u'date to execute',
-    )
-    expires = models.DateTimeField(_(u'expires'), null=True)
-    result = models.TextField(_(u'result'), null=True)
-    traceback = models.TextField(_(u'traceback'), null=True)
+    tstamp = models.DateTimeField(_('event received at'), db_index=True)
+    args = models.TextField(_('Arguments'), null=True)
+    kwargs = models.TextField(_('Keyword arguments'), null=True)
+    eta = models.DateTimeField(_('ETA'), null=True)
+    expires = models.DateTimeField(_('expires'), null=True)
+    result = models.TextField(_('result'), null=True)
+    traceback = models.TextField(_('traceback'), null=True)
     runtime = models.FloatField(
-        _(u'execution time'), null=True,
-        help_text=_(u'in seconds if task successful'),
+        _('execution time'), null=True,
+        help_text=_('in seconds if task succeeded'),
     )
-    retries = models.IntegerField(_(u'number of retries'), default=0)
+    retries = models.IntegerField(_('number of retries'), default=0)
     worker = models.ForeignKey(
         WorkerState, null=True, verbose_name=_('worker'),
     )
@@ -348,8 +341,8 @@ class TaskState(models.Model):
 
     class Meta:
         """Model meta-data."""
-        verbose_name = _(u'task')
-        verbose_name_plural = _(u'tasks')
+        verbose_name = _('task')
+        verbose_name_plural = _('tasks')
         get_latest_by = 'tstamp'
         ordering = ['-tstamp']
 
@@ -358,15 +351,12 @@ class TaskState(models.Model):
 
     def __unicode__(self):
         name = self.name or 'UNKNOWN'
-        s = u'%s %s %s' % (self.state.ljust(10),
-                           self.task_id.ljust(36),
-                           name)
+        s = '{0.state:<10} {0.task_id:<36} {1}'.format(self, name)
         if self.eta:
-            s += u' eta:%s' % (self.eta, )
+            s += ' eta:{0.eta}'.format(self)
         return s
 
     def __repr__(self):
-        return '<TaskState: %s %s(%s) ts:%s>' % (self.state,
-                                                 self.name or 'UNKNOWN',
-                                                 self.task_id,
-                                                 self.tstamp)
+        return '<TaskState: {0.state} {1}[{0.task_id}] ts:{0.tstamp}>'.format(
+            self, self.name or 'UNKNOWN',
+        )
