@@ -2,15 +2,15 @@ from __future__ import absolute_import
 
 import logging
 
-from warnings import warn
+from multiprocessing.util import Finalize
 
-from anyjson import deserialize, serialize
+from anyjson import loads, dumps
 from celery import current_app
 from celery import schedules
 from celery.beat import Scheduler, ScheduleEntry
 from celery.utils.encoding import safe_str, safe_repr
+from celery.utils.log import get_logger
 from celery.utils.timeutils import is_naive
-from kombu.utils.finalize import Finalize
 
 from django.db import transaction
 from django.core.exceptions import ObjectDoesNotExist
@@ -24,6 +24,13 @@ from .utils import DATABASE_ERRORS, make_aware
 # changes to the schedule into account.
 DEFAULT_MAX_INTERVAL = 5  # seconds
 
+ADD_ENTRY_ERROR = """\
+Couldn't add entry %r to database schedule: %r. Contents: %r
+"""
+
+logger = get_logger(__name__)
+debug, info, error = logger.debug, logger.info, logger.error
+
 
 class ModelEntry(ScheduleEntry):
     model_schedules = ((schedules.crontab, CrontabSchedule, 'crontab'),
@@ -36,8 +43,8 @@ class ModelEntry(ScheduleEntry):
         self.task = model.task
         self.schedule = model.schedule
         try:
-            self.args = deserialize(model.args or u'[]')
-            self.kwargs = deserialize(model.kwargs or u'{}')
+            self.args = loads(model.args or '[]')
+            self.kwargs = loads(model.kwargs or '{}')
         except ValueError:
             logging.error('Failed to serialize arguments for %s.', self.name,
                           exc_info=1)
@@ -92,7 +99,8 @@ class ModelEntry(ScheduleEntry):
                 model_schedule = model_type.from_schedule(schedule)
                 model_schedule.save()
                 return model_schedule, model_field
-        raise ValueError('Cannot convert schedule type %r to model' % schedule)
+        raise ValueError(
+            'Cannot convert schedule type {0!r} to model'.format(schedule))
 
     @classmethod
     def from_entry(cls, name, skip_fields=('relative', 'options'), **entry):
@@ -103,8 +111,8 @@ class ModelEntry(ScheduleEntry):
         schedule = fields.pop('schedule')
         model_schedule, model_field = cls.to_model_schedule(schedule)
         fields[model_field] = model_schedule
-        fields['args'] = serialize(fields.get('args') or [])
-        fields['kwargs'] = serialize(fields.get('kwargs') or {})
+        fields['args'] = dumps(fields.get('args') or [])
+        fields['kwargs'] = dumps(fields.get('kwargs') or {})
         fields['queue'] = options.get('queue')
         fields['exchange'] = options.get('exchange')
         fields['routing_key'] = options.get('routing_key')
@@ -113,11 +121,10 @@ class ModelEntry(ScheduleEntry):
         ))
 
     def __repr__(self):
-        return '<ModelEntry: %s %s(*%s, **%s) {%s}>' % (safe_str(self.name),
-                                                        self.task,
-                                                        safe_repr(self.args),
-                                                        safe_repr(self.kwargs),
-                                                        self.schedule)
+        return '<ModelEntry: {0} {1}(*{2}, **{3}) {{4}}>'.format(
+            safe_str(self.name), self.task, safe_repr(self.args),
+            safe_repr(self.kwargs), self.schedule,
+        )
 
 
 class DatabaseScheduler(Scheduler):
@@ -142,7 +149,7 @@ class DatabaseScheduler(Scheduler):
         self.update_from_dict(self.app.conf.CELERYBEAT_SCHEDULE)
 
     def all_as_schedule(self):
-        self.logger.debug('DatabaseScheduler: Fetching database schedule')
+        debug('DatabaseScheduler: Fetching database schedule')
         s = {}
         for model in self.Model.objects.enabled():
             try:
@@ -163,8 +170,8 @@ class DatabaseScheduler(Scheduler):
                 pass  # not in transaction management.
 
             last, ts = self._last_timestamp, self.Changes.last_change()
-        except DATABASE_ERRORS, exc:
-            warn(RuntimeWarning('Database gave error: %r' % (exc, )))
+        except DATABASE_ERRORS as exc:
+            error('Database gave error: %r', exc, exc_info=1)
             return False
         try:
             if ts and ts > (last if last else ts):
@@ -182,7 +189,7 @@ class DatabaseScheduler(Scheduler):
 
     @transaction.commit_manually
     def sync(self):
-        self.logger.info('Writing entries...')
+        info('Writing entries...')
         _tried = set()
         try:
             try:
@@ -198,20 +205,18 @@ class DatabaseScheduler(Scheduler):
                 raise
             else:
                 transaction.commit()
-        except DATABASE_ERRORS, exc:
+        except DATABASE_ERRORS as exc:
             # retry later
             self._dirty |= _tried
-            warn(RuntimeWarning('Database error while sync: %r' % (exc, )))
+            error('Database error while sync: %r', exc, exc_info=1)
 
     def update_from_dict(self, dict_):
         s = {}
         for name, entry in dict_.items():
             try:
                 s[name] = self.Entry.from_entry(name, **entry)
-            except Exception, exc:
-                self.logger.error(
-                    'Could not add entry %r to database schedule: %r. '
-                    'Contents: %r' % (name, exc, entry))
+            except Exception as exc:
+                error(ADD_ENTRY_ERROR, name, exc, entry)
         self.schedule.update(s)
 
     def install_default_entries(self, data):
@@ -230,19 +235,18 @@ class DatabaseScheduler(Scheduler):
     def schedule(self):
         update = False
         if not self._initial_read:
-            self.logger.debug('DatabaseScheduler: intial read')
+            debug('DatabaseScheduler: intial read')
             update = True
             self._initial_read = True
         elif self.schedule_changed():
-            self.logger.info('DatabaseScheduler: Schedule changed.')
+            info('DatabaseScheduler: Schedule changed.')
             update = True
 
         if update:
             self.sync()
             self._schedule = self.all_as_schedule()
-            if self.logger.isEnabledFor(logging.DEBUG):
-                self.logger.debug(
-                    'Current schedule:\n' + '\n'.join(
-                        repr(entry) for entry in self._schedule.values())
+            if logger.isEnabledFor(logging.DEBUG):
+                debug('Current schedule:\n%s', '\n'.join(
+                    repr(entry) for entry in self._schedule.itervalues()),
                 )
         return self._schedule
