@@ -1,8 +1,7 @@
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 from collections import defaultdict
 from datetime import datetime, timedelta
-from time import time
 
 from django.db import transaction
 from django.conf import settings
@@ -10,12 +9,13 @@ from django.conf import settings
 from celery import states
 from celery.events.state import Task
 from celery.events.snapshot import Polaroid
+from celery.five import monotonic
+from celery.utils.log import get_logger
 from celery.utils.timeutils import maybe_iso8601
 
 from .models import WorkerState, TaskState
 from .utils import maybe_make_aware
 
-
 WORKER_UPDATE_FREQ = 60  # limit worker timestamp write freq.
 SUCCESS_STATES = frozenset([states.SUCCESS])
 
@@ -28,6 +28,9 @@ EXPIRE_PENDING = getattr(settings, 'CELERYCAM_EXPIRE_PENDING',
                          timedelta(days=5))
 NOT_SAVED_ATTRIBUTES = frozenset(['name', 'args', 'kwargs', 'eta'])
 
+logger = get_logger(__name__)
+debug = logger.debug
+
 
 def aware_tstamp(secs):
     """Event timestamps uses the local timezone."""
@@ -59,12 +62,13 @@ class Camera(Polaroid):
 
     def handle_worker(self, (hostname, worker)):
         last_write, obj = self._last_worker_write[hostname]
-        if not last_write or time() - last_write > self.worker_update_freq:
+        if not last_write or \
+                monotonic() - last_write > self.worker_update_freq:
             obj = self.WorkerState.objects.update_or_create(
                 hostname=hostname,
                 defaults={'last_heartbeat': self.get_heartbeat(worker)},
             )
-            self._last_worker_write[hostname] = (time(), obj)
+            self._last_worker_write[hostname] = (monotonic(), obj)
         return obj
 
     def handle_task(self, (uuid, task), worker=None):
@@ -120,19 +124,6 @@ class Camera(Polaroid):
 
         return obj
 
-    def _autocommit(self, fun):
-        try:
-            fun()
-        except (KeyboardInterrupt, SystemExit):
-            transaction.commit()
-            raise
-        except Exception:
-            transaction.rollback()
-            raise
-        else:
-            transaction.commit()
-
-    @transaction.commit_manually
     def on_shutter(self, state, commit_every=100):
         if not state.event_count:
             transaction.commit()
@@ -144,18 +135,16 @@ class Camera(Polaroid):
                 if not i % commit_every:
                     transaction.commit()
 
-        self._autocommit(lambda: map(self.handle_worker,
-                                     state.workers.items()))
-        self._autocommit(_handle_tasks)
+        for worker in state.workers.items():
+            self.handle_worker(worker)
+        _handle_tasks()
 
     def on_cleanup(self):
         dirty = sum(self.TaskState.objects.expire_by_states(states, expires)
                     for states, expires in self.expire_states.items())
         if dirty:
-            self.logger.debug(
-                'Cleanup: Marked %s objects as dirty.' % (dirty, ),
-            )
+            debug('Cleanup: Marked %s objects as dirty.', dirty)
             self.TaskState.objects.purge()
-            self.logger.debug('Cleanup: %s objects purged.' % (dirty, ))
+            debug('Cleanup: %s objects purged.', dirty)
             return dirty
         return 0
